@@ -1,29 +1,16 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingsakonadicheckjobtest.h"
-#include "importimapsettingspasswordtest.h"
 #include "../checks/importimapsettingsakonadicheckjob.h"
+#include "importimapsettingspasswordtest.h"
 
-#include <QTest>
-#include <QStandardPaths>
 #include <QSignalSpy>
+#include <QStandardPaths>
+#include <QTest>
 
 Q_DECLARE_METATYPE(SieveEditorUtil::SieveServerConfig)
 ImportImapSettingsAkonadiCheckJobTest::ImportImapSettingsAkonadiCheckJobTest(QObject *parent)
@@ -129,7 +116,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings2.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings2.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
     settings2.sieveSettings.userName = QStringLiteral("b");
-    settings2.sieveSettings.serverName = QStringLiteral("bla.foo.com"); //TODO
+    settings2.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
     settings2.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
     settings2.sieveSettings.port = 150;
 
@@ -144,7 +131,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings3.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings3.sieveSettings.userName = QStringLiteral("b");
     settings3.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
-    settings3.sieveSettings.serverName = QStringLiteral("bla.foo.com"); //TODO
+    settings3.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
     settings3.sieveSettings.port = 150;
 
     QTest::newRow("usecustomsieveconfig2") << QStringLiteral("/config/usecustomsieveconfig2") << QStringLiteral("akonadi_kolab_resource_0rc") << settings3;
@@ -158,7 +145,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings4.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings4.sieveSettings.userName = QStringLiteral("b");
     settings4.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
-    settings4.sieveSettings.serverName = QStringLiteral("bla.foo.com"); //TODO
+    settings4.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
     settings4.sieveSettings.port = 150;
 
     QTest::newRow("usecustomsieveconfig3") << QStringLiteral("/config/usecustomsieveconfig3") << QStringLiteral("akonadi_kolab_resource_0rc") << settings4;
@@ -171,7 +158,7 @@ void ImportImapSettingsAkonadiCheckJobTest::shouldImportSieveSettings_data()
     settings5.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::SSLorTLS);
     settings5.sieveImapAccountSettings.setPassword(QStringLiteral("password_imap"));
     settings5.sieveSettings.userName = QStringLiteral("b");
-    settings5.sieveSettings.serverName = QStringLiteral("bla.foo.com"); //TODO
+    settings5.sieveSettings.serverName = QStringLiteral("bla.foo.com"); // TODO
     settings5.sieveSettings.password = QStringLiteral("password_custom_sieve_imap");
     settings5.sieveSettings.port = 150;
 
