@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingprogresspage.h"
-#include "sieveeditor_debug.h"
 #include "checks/abstractimapsettingscheckjob.h"
-#include <QVBoxLayout>
+#include "sieveeditor_debug.h"
 #include <KLocalizedString>
 #include <QTextEdit>
+#include <QVBoxLayout>
 
 ImportImapSettingProgressPage::ImportImapSettingProgressPage(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mProgressTextEdit = new QTextEdit(this);
     mProgressTextEdit->setObjectName(QStringLiteral("textedit"));
@@ -80,13 +67,9 @@ void ImportImapSettingProgressPage::start()
 
 void ImportImapSettingProgressPage::slotImportSettingsDone(const QString &name, const SieveEditorUtil::SieveServerConfig &settings)
 {
-    const QString str{
-        i18n("Import settings from %1...", name)
-    };
+    const QString str{i18n("Import settings from %1...", name)};
     addProgressInfo(str);
-    const QString summaryStr{
-        i18n("Import settings from %1 done", name)
-    };
+    const QString summaryStr{i18n("Import settings from %1 done", name)};
     Q_EMIT addSummaryInfo(summaryStr);
     SieveEditorUtil::addServerSieveConfig(settings);
     mSettingsFound = true;
