@@ -1,36 +1,23 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditor-version.h"
 #include "sieveeditormainwindow.h"
 #include <KAboutData>
+#include <KCrash>
+#include <KDBusService>
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 #include <QApplication>
-#include <KDBusService>
 #include <QCommandLineParser>
-#include <KCrash>
 #include <QTextStream>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#include <KUserFeedback/Provider>
 #include <KUserFeedback/FeedbackConfigWidget>
+#include <KUserFeedback/Provider>
 #endif
 
 int main(int argc, char **argv)
@@ -52,7 +39,7 @@ int main(int argc, char **argv)
                          QStringLiteral(SIEVEEDITOR_VERSION),
                          i18n("Sieve Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2013-2020 sieveeditor authors"));
+                         i18n("Copyright © 2013-2021 sieveeditor authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
@@ -75,7 +62,7 @@ int main(int argc, char **argv)
 
     KDBusService service(KDBusService::Unique);
 
-    auto *mw = new SieveEditorMainWindow();
+    auto mw = new SieveEditorMainWindow();
     mw->show();
     const int val = app.exec();
     return val;
