@@ -1,35 +1,22 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditormainwidget.h"
-#include "sieveeditorscriptmanagerwidget.h"
-#include "sieveeditorpagewidget.h"
-#include "sieveeditortabwidget.h"
 #include "sieveeditoremptytabwidgetlabel.h"
+#include "sieveeditorpagewidget.h"
+#include "sieveeditorscriptmanagerwidget.h"
+#include "sieveeditortabwidget.h"
 #include <KSieveUi/SieveEditor>
 
-#include <KLocalizedString>
+#include <KColorScheme>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KSharedConfig>
 #include <QTabWidget>
-#include <KColorScheme>
-#include <KMessageBox>
 
 #include <QStackedWidget>
 #include <QTabBar>
@@ -78,7 +65,7 @@ SieveEditorMainWidget::~SieveEditorMainWidget()
 QWidget *SieveEditorMainWidget::hasExistingPage(const QUrl &url)
 {
     for (int i = 0; i < mTabWidget->count(); ++i) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
+        auto page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             if (page->currentUrl() == url) {
                 return page;
@@ -111,7 +98,7 @@ void SieveEditorMainWidget::slotScriptRenamed(const QUrl &oldUrl, const QUrl &ne
 {
     QWidget *page = hasExistingPage(oldUrl);
     if (page) {
-        if (auto *editor = qobject_cast<SieveEditorPageWidget *>(page)) {
+        if (auto editor = qobject_cast<SieveEditorPageWidget *>(page)) {
             editor->setCurrentUrl(newUrl);
             const QString newScriptName = newUrl.fileName();
             mTabWidget->setTabText(mTabWidget->indexOf(page), newScriptName);
@@ -127,7 +114,7 @@ void SieveEditorMainWidget::slotCreateScriptPage(const KSieveUi::ManageSieveWidg
     if (page) {
         mTabWidget->setCurrentWidget(page);
     } else {
-        auto *editor = new SieveEditorPageWidget;
+        auto editor = new SieveEditorPageWidget;
         connect(editor, &SieveEditorPageWidget::refreshList, this, &SieveEditorMainWidget::updateScriptList);
         connect(editor, &SieveEditorPageWidget::scriptModified, this, &SieveEditorMainWidget::slotScriptModified);
         connect(editor, &SieveEditorPageWidget::modeEditorChanged, this, &SieveEditorMainWidget::modeEditorChanged);
@@ -181,7 +168,7 @@ void SieveEditorMainWidget::uploadScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->uploadScript();
         }
@@ -192,7 +179,7 @@ bool SieveEditorMainWidget::needToSaveScript()
 {
     bool scriptSaved = false;
     for (int i = 0; i < mTabWidget->count(); ++i) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
+        auto page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             const bool result = page->needToSaveScript();
             if (result) {
@@ -212,7 +199,7 @@ bool SieveEditorMainWidget::isUndoAvailable() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isUndoAvailable();
         }
@@ -224,7 +211,7 @@ bool SieveEditorMainWidget::isRedoAvailable() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isRedoAvailable();
         }
@@ -236,7 +223,7 @@ bool SieveEditorMainWidget::isWordWrap() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isWordWrap();
         }
@@ -248,7 +235,7 @@ bool SieveEditorMainWidget::hasSelection() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->hasSelection();
         }
@@ -260,7 +247,7 @@ void SieveEditorMainWidget::slotSelectAll()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->selectAll();
         }
@@ -271,7 +258,7 @@ void SieveEditorMainWidget::slotCopy()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->copy();
         }
@@ -282,7 +269,7 @@ void SieveEditorMainWidget::slotPaste()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->paste();
         }
@@ -293,7 +280,7 @@ void SieveEditorMainWidget::slotCut()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->cut();
         }
@@ -304,7 +291,7 @@ void SieveEditorMainWidget::slotUndo()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->undo();
         }
@@ -315,7 +302,7 @@ void SieveEditorMainWidget::slotRedo()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->redo();
         }
@@ -326,7 +313,7 @@ void SieveEditorMainWidget::slotGoToLine()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->goToLine();
         }
@@ -337,7 +324,7 @@ void SieveEditorMainWidget::slotFind()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->find();
         }
@@ -348,7 +335,7 @@ void SieveEditorMainWidget::slotReplace()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->replace();
         }
@@ -359,7 +346,7 @@ void SieveEditorMainWidget::slotShareScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->shareScript();
         }
@@ -370,7 +357,7 @@ QString SieveEditorMainWidget::currentText() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentText();
         }
@@ -382,7 +369,7 @@ void SieveEditorMainWidget::slotCreateRulesGraphically()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->createRulesGraphically();
         }
@@ -393,7 +380,7 @@ void SieveEditorMainWidget::slotCheckSyntax()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->checkSyntax();
         }
@@ -404,7 +391,7 @@ void SieveEditorMainWidget::slotComment()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->comment();
         }
@@ -415,7 +402,7 @@ void SieveEditorMainWidget::slotUncomment()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->uncomment();
         }
@@ -426,7 +413,7 @@ void SieveEditorMainWidget::slotImport()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->import();
         }
@@ -437,7 +424,7 @@ void SieveEditorMainWidget::slotCheckSpelling()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->checkSpelling();
         }
@@ -448,7 +435,7 @@ void SieveEditorMainWidget::slotSaveAs()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->saveAs();
         }
@@ -459,7 +446,7 @@ void SieveEditorMainWidget::slotReverseCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->reverseCase();
         }
@@ -470,7 +457,7 @@ void SieveEditorMainWidget::slotDebugSieveScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->debugSieveScript();
         }
@@ -481,7 +468,7 @@ void SieveEditorMainWidget::slotUpperCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->upperCase();
         }
@@ -492,7 +479,7 @@ void SieveEditorMainWidget::slotSentenceCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->sentenceCase();
         }
@@ -503,7 +490,7 @@ void SieveEditorMainWidget::slotLowerCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->lowerCase();
         }
@@ -525,7 +512,7 @@ void SieveEditorMainWidget::slotZoomIn()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomIn();
         }
@@ -536,7 +523,7 @@ void SieveEditorMainWidget::slotZoomOut()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomOut();
         }
@@ -547,7 +534,7 @@ void SieveEditorMainWidget::slotZoomReset()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomReset();
         }
@@ -558,7 +545,7 @@ void SieveEditorMainWidget::slotWordWrap(bool state)
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->wordWrap(state);
         }
@@ -569,7 +556,7 @@ void SieveEditorMainWidget::slotPrintPreview()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->printPreview();
         }
@@ -580,7 +567,7 @@ void SieveEditorMainWidget::slotPrint()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->print();
         }
@@ -599,7 +586,7 @@ void SieveEditorMainWidget::slotGeneralPaletteChanged()
 
 void SieveEditorMainWidget::forceCloseTab(int index)
 {
-    auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
+    auto page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
     if (page) {
         mTabWidget->removeTab(index);
         delete page;
@@ -609,7 +596,7 @@ void SieveEditorMainWidget::forceCloseTab(int index)
 
 void SieveEditorMainWidget::slotTabCloseRequested(int index)
 {
-    auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
+    auto page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
     if (page) {
         if (page->isModified()) {
             const int result = KMessageBox::questionYesNoCancel(this, i18n("Script was modified. Do you want to save before closing?"), i18n("Close script"));
@@ -648,7 +635,7 @@ KSieveUi::SieveEditorWidget::EditorMode SieveEditorMainWidget::pageMode() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->pageMode();
         }
@@ -660,7 +647,7 @@ void SieveEditorMainWidget::openBookmarkUrl(const QUrl &url)
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->openBookmarkUrl(url);
         }
@@ -671,7 +658,7 @@ QString SieveEditorMainWidget::currentHelpTitle() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentHelpTitle();
         }
@@ -683,7 +670,7 @@ QUrl SieveEditorMainWidget::currentHelpUrl() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentHelpUrl();
         }
@@ -695,7 +682,7 @@ bool SieveEditorMainWidget::printSupportEnabled() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->printSupportEnabled();
         }
@@ -707,7 +694,7 @@ bool SieveEditorMainWidget::isTextEditor() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isTextEditor();
         }
