@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIEVEEDITORMAINWINDOW_H
-#define SIEVEEDITORMAINWINDOW_H
+#pragma once
 
-#include <KXmlGuiWindow>
 #include "libsieveeditor_export.h"
+#include <KXmlGuiWindow>
 class QAction;
 class SieveEditorCentralWidget;
 class QLabel;
 class SieveEditorBookmarks;
 class KActionMenu;
-namespace PimCommon {
+namespace PimCommon
+{
 class KActionMenuChangeCase;
 }
 class LIBSIEVEEDITOR_EXPORT SieveEditorMainWindow : public KXmlGuiWindow
@@ -60,6 +47,7 @@ private:
     void slotCopyAvailable(bool b);
     void slotOpenBookmarkUrl(const QUrl &url);
     void slotImportImapSettings();
+
 private:
     void initStatusBar();
     void readConfig();
@@ -106,4 +94,3 @@ private:
     bool mNetworkIsDown = false;
 };
 
-#endif // SIEVEEDITORMAINWINDOW_H
