@@ -1,26 +1,13 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditormanagesievewidget.h"
-#include "sieveeditorutil.h"
-#include <KSieveUi/SieveTreeWidgetItem>
+#include "readserversieveconfigjob.h"
 #include <KSieveUi/ManageSieveTreeView>
+#include <KSieveUi/SieveTreeWidgetItem>
 
 #include <KManageSieve/SieveJob>
 
@@ -41,16 +28,14 @@ bool SieveEditorManageSieveWidget::refreshList()
 {
     bool noImapFound = true;
     SieveTreeWidgetItem *last = nullptr;
-
-    const QVector<SieveEditorUtil::SieveServerConfig> listConfig = SieveEditorUtil::readServerSieveConfig();
-    for (const SieveEditorUtil::SieveServerConfig &conf : listConfig) {
+    for (const SieveEditorUtil::SieveServerConfig &conf : mSieveServerSettings) {
         last = new SieveTreeWidgetItem(treeView(), last);
         last->setText(0, conf.sieveSettings.serverName + QStringLiteral(" (%1)").arg(conf.sieveSettings.userName));
         last->setIcon(0, QIcon::fromTheme(QStringLiteral("network-server")));
 
         const QUrl u = conf.url();
         if (u.isEmpty()) {
-            auto *item = new QTreeWidgetItem(last);
+            auto item = new QTreeWidgetItem(last);
             item->setText(0, i18n("No Sieve URL configured"));
             item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
             treeView()->expandItem(last);
@@ -69,3 +54,16 @@ bool SieveEditorManageSieveWidget::refreshList()
     }
     return noImapFound;
 }
+
+void SieveEditorManageSieveWidget::updateSieveSettings()
+{
+    ReadServerSieveConfigJob *job = new ReadServerSieveConfigJob(this);
+    connect(job, &ReadServerSieveConfigJob::finished, this, &SieveEditorManageSieveWidget::slotReadServerSieveConfigDone);
+    job->start();
+}
+
+void SieveEditorManageSieveWidget::slotReadServerSieveConfigDone(const QVector<SieveEditorUtil::SieveServerConfig> &lstConfig)
+{
+    mSieveServerSettings = lstConfig;
+    Q_EMIT updateSieveSettingsDone();
+}
